var assertOk = function (ok, message) {
    if (!ok) {
        throw new Error(message);
    }
};
export var parsePage = function (window) {
    var _a, _b, _c, _d;
    var pages = window.document.querySelectorAll("#a-page");
    var page = pages[pages.length - 1]; // select child #a-page if nested #a-page
    var title = page.querySelector("h3.kp-notebook-metadata");
    var author = page.querySelector("h3 + p.kp-notebook-metadata");
    var coverImage = page.querySelector(".kp-notebook-cover-image-border");
    var asinNode = page.querySelector("[id=\"kp-notebook-annotations-asin\"]");
    var asinValue = asinNode.value;
    assertOk(coverImage, "coverImage not found");
    assertOk(asinNode, "ASIN not found");
    assertOk(title, "title not found");
    assertOk(author, "author not found");
    var annotationNodes = page.querySelectorAll("#kp-notebook-annotations > div.a-row");
    assertOk(annotationNodes.length > 0, "annotations not found");
    var annotations = Array.from(annotationNodes)
        .filter(function (annotation) {
        return annotation.getAttribute("id") !== "empty-annotations-pane";
    })
        .map(function (annotation) {
        var noteNode = annotation.querySelector("[id=\"note\"]");
        var noteValue = noteNode && noteNode.textContent ? noteNode.textContent : undefined;
        var locationNode = annotation.querySelector("[id=\"kp-annotation-location\"]");
        assertOk(locationNode, "locationNode is not found");
        var highlightNode = annotation.querySelector("[id=\"highlight\"]");
        // Kindle disappear the highlight, see https://github.com/azu/kindle-highlight-to-markdown/issues/3
        // Sorry, we’re unable to display this type of content.
        var isEmptyHighlight = highlightNode === null;
        var highlightText = isEmptyHighlight ? "" : highlightNode.textContent;
        assertOk(highlightText !== undefined, "highlightText is not found");
        var locationNumber = Number(locationNode.value);
        return {
            note: noteValue,
            locationNumber: locationNumber,
            highlight: highlightText,
            kindleUrl: "kindle://book?action=open&asin=".concat(asinValue, "&location=").concat(locationNumber)
        };
    });
    return {
        title: (_b = (_a = title.textContent) === null || _a === void 0 ? void 0 : _a.trim()) !== null && _b !== void 0 ? _b : "",
        author: (_d = (_c = author.textContent) === null || _c === void 0 ? void 0 : _c.trim()) !== null && _d !== void 0 ? _d : "",
        coverImageUrl: coverImage.src,
        asin: asinValue,
        url: "https://www.amazon.co.jp/dp/".concat(asinValue),
        annotations: annotations
    };
};
//# sourceMappingURL=parse.js.map